/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.lpkg.deployer;

import java.io.File;

import java.util.List;

import org.osgi.framework.Bundle;

/**
 * @author Shuyang Zhou
 */
public interface LPKGVerifier {

	/**
	 * Verifies that the file is deployable as an LPKG bundle.
	 *
	 * @param  lpkgFile the file to verify
	 * @return the older bundles with the same symbolic name and lower versions.
	 *         The older bundles must be uninstalled before the new LPKG file
	 *         can be installed. When no older bundles are found, this method
	 *         returns an empty list.
	 * @throws LPKGVerifyException if the LPKG file does not contain a
	 *         <code>liferay-marketplace.properties</code> file, if the
	 *         <code>liferay-marketplace.properties</code> file does not have a
	 *         valid title and version, or if a bundle already exists with the
	 *         same symbolic name and version
	 */
	public List<Bundle> verify(File lpkgFile) throws LPKGVerifyException;

}