/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.lpkg.deployer.internal;

import com.liferay.petra.process.ProcessCallable;
import com.liferay.petra.process.ProcessException;
import com.liferay.portal.kernel.io.unsync.UnsyncByteArrayOutputStream;
import com.liferay.portal.target.platform.indexer.TargetPlatformIndexerUtil;

import java.io.File;

import java.util.List;

/**
 * @author Shuyang Zhou
 */
public class TargetPlatformIndexerProcessCallable
	implements ProcessCallable<byte[]> {

	public TargetPlatformIndexerProcessCallable(
		List<File> additionalJarFiles, long stopWaitTimeout,
		String... dirNames) {

		_additionalJarFiles = additionalJarFiles;
		_stopWaitTimeout = stopWaitTimeout;
		_dirNames = dirNames;
	}

	@Override
	public byte[] call() throws ProcessException {
		try {
			UnsyncByteArrayOutputStream unsyncByteArrayOutputStream =
				new UnsyncByteArrayOutputStream();

			TargetPlatformIndexerUtil.indexTargetPlatform(
				unsyncByteArrayOutputStream, _additionalJarFiles,
				_stopWaitTimeout, _dirNames);

			return unsyncByteArrayOutputStream.toByteArray();
		}
		catch (Exception e) {
			throw new ProcessException(e);
		}
	}

	@Override
	public String toString() {
		return "Target Platform Indexer";
	}

	private static final long serialVersionUID = 1L;

	private final List<File> _additionalJarFiles;
	private final String[] _dirNames;
	private final long _stopWaitTimeout;

}