/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.lpkg.deployer.internal;

import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.Validator;

import java.net.MalformedURLException;
import java.net.URL;

import org.osgi.framework.Constants;
import org.osgi.framework.Version;
import org.osgi.service.url.AbstractURLStreamHandlerService;

/**
 * @author Matthew Tambara
 */
public class WABWrapperUtil {

	public static String generateWABLocation(
		URL lpkgURL, Version version, String contextName) {

		return "webbundle:".concat(
			_generateFileWithQueryString(lpkgURL, version, contextName));
	}

	public static URL generateWABLocationURL(
			URL lpkgURL, Version version, String contextName,
			AbstractURLStreamHandlerService abstractURLStreamHandlerService)
		throws MalformedURLException {

		return new URL(
			"webbundle", null, -1,
			_generateFileWithQueryString(lpkgURL, version, contextName),
			abstractURLStreamHandlerService);
	}

	private static String _generateFileWithQueryString(
		URL lpkgURL, Version version, String contextName) {

		StringBundler sb = new StringBundler(10);

		sb.append(lpkgURL.getPath());
		sb.append(StringPool.QUESTION);
		sb.append(Constants.BUNDLE_VERSION);
		sb.append(StringPool.EQUAL);
		sb.append(version);
		sb.append("&Web-ContextPath=/");
		sb.append(contextName);
		sb.append("&protocol=lpkg");

		String query = lpkgURL.getQuery();

		if (Validator.isNotNull(query)) {
			sb.append(StringPool.AMPERSAND);
			sb.append(query);
		}

		return sb.toString();
	}

}